@@ -49,13 +49,13 @@
 
 package com.openexchange.client.onboarding.json;
 
-import java.util.Collection;
 import java.util.Map;
 import com.google.common.collect.ImmutableMap;
 import com.openexchange.ajax.requesthandler.AJAXActionService;
 import com.openexchange.ajax.requesthandler.AJAXActionServiceFactory;
 import com.openexchange.client.onboarding.json.actions.AllScenariosAction;
 import com.openexchange.client.onboarding.json.actions.ConfigAction;
+import com.openexchange.client.onboarding.json.actions.DevicesAction;
 import com.openexchange.client.onboarding.json.actions.ExecuteAction;
 import com.openexchange.client.onboarding.json.actions.GetScenarioAction;
 import com.openexchange.exception.OXException;
@@ -80,6 +80,7 @@ public class OnboardingActionFactory implements AJAXActionServiceFactory {
         super();
         ImmutableMap.Builder<String, AJAXActionService> actions = ImmutableMap.builder();
         actions.put("config", new ConfigAction(services));
+        actions.put("devices", new DevicesAction(services));
         actions.put("get", new GetScenarioAction(services));
         actions.put("scenarios", new AllScenariosAction(services));
         actions.put("execute", new ExecuteAction(services));
@@ -91,9 +92,4 @@ public class OnboardingActionFactory implements AJAXActionServiceFactory {
         return actions.get(action);
     }
 
-    @Override
-    public Collection<?> getSupportedServices() {
-        return null;
-    }
-
 }
